.. expect: default role used (hint: for inline literals, use double backticks) (default-role)

Unless it has been set to something explicitly, the default role is
`emphasis` and normally remains unused.
